Release 1.3.1
-------------

(Published February, 2015)

The authoritative state for any known issue can be found in `GitHub issues <https://github.com/arista-eosplus/ztpserver/issues>`_.

Bug fixes
^^^^^^^^^

* fixes *pip* install/uninstall issues

